@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 1996, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2015, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -30,6 +30,8 @@ import java.io.File;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLClassLoader;
+import java.security.AccessController;
+import java.security.PrivilegedAction;
 import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -279,8 +281,8 @@ public class Interview
         // name is not null
         if (!name.equals(bundleName)) {
             Class c = getClass();
-            ClassLoader cl = c.getClassLoader();
-            String rn;
+            final ClassLoader cl = c.getClassLoader();
+            final String rn;
             if (name.startsWith("/"))
                 rn = name.substring(1);
             else {
@@ -289,7 +291,12 @@ public class Interview
                 rn = pn + "." + name;
             }
             //System.err.println("INT: looking for bundle: " + rn);
-            bundle = ResourceBundle.getBundle(rn, Locale.getDefault(), cl);
+            bundle = AccessController.doPrivileged(
+                    new PrivilegedAction<ResourceBundle>() {
+                        public ResourceBundle run() {
+                            return ResourceBundle.getBundle(rn, Locale.getDefault(), cl);
+                        }
+                    });
             bundleName = name;
         }
     }
@@ -308,15 +315,20 @@ public class Interview
      * cannot be found.
      * @see #getResourceBundle
      */
-    protected void setResourceBundle(String name, File file)
+    protected void setResourceBundle(final String name, File file)
             throws MissingResourceException {
         if (bundleName != null && bundleName.equals(name)) {
             return;
         }
         try {
             URL[] url = {new URL("file:" + file.getAbsolutePath() + "/")};
-            URLClassLoader cl = new URLClassLoader(url);
-            bundle = ResourceBundle.getBundle(name, Locale.getDefault(), cl);
+            final URLClassLoader cl = new URLClassLoader(url);
+            bundle = AccessController.doPrivileged(
+                    new PrivilegedAction<ResourceBundle>() {
+                        public ResourceBundle run() {
+                            return ResourceBundle.getBundle(name, Locale.getDefault(), cl);
+                        }
+                    });
             bundleName = name;
         } catch (MalformedURLException e) {
         }
@@ -1978,11 +1990,62 @@ public class Interview
      * possible during construction.  It is recommended that you select
      * the most recent version possible when developing a new interview.
      * As this interview ages and the harness libraries progress, the
-     * interview should remain locked at the current behavior.
+     * interview should remain locked at the current behavior.  Each subsequent
+     * version works under the assumption that the behavior of all previous
+     * versions is also enabled, there is no way to select individual behaviors.
+     *
+     * <p>
+     * The version numbers are effectively an indication of the harness version
+     * where the behavior was added (32 = 3.2, 50 = 5.0).  Gaps in numbering
+     * would indicate that no incompatible behavior changes occurred.
+     * </p>
+     *
+     * <p>
+     * Select PRE_32 behavior to select behaviors prior to 3.2.
+     * </p>
+     *
+     * <p>
+     * In Version 32, the first versioned semantic change was introduced.
+     * Interviews will generally request SEMANTIC_PRE_32 for old semantics.
+     * This version has the behavioral changes:
+     * <dl>
+     * <dt>ChoiceQuestion</dt>
+     * <dd>If the value is reset to null, resulting in the value being
+     * "cleared", new behavior simply calls <code>clear()</code> to do this.  Old
+     * behavior was to select either the last value or first possible
+     * choice (from the array of possible choices) THEN call <code>updatePath()</code>
+     * and <code>setEdited()</code>.</dd>
+     * <dt>FileListQuestion</dt>
+     * <dd>During construction, <code>clear()</code> will be called before the
+     *    default value is set, in older implementations it was not called.</dd>
+     * <dt>FileQuestion</dt>
+     * <dd>During construction, <code>clear()</code> will be called before the
+     *    default value is set, in older implementations it was not called.</dd>
+     * </dl>
+     * </p>
+     *
+     * <p>
+     * In Version 43 changes to the way in which <code>export()</code> works were
+     * introduced.  Earlier than this version, the list of questions to call
+     * <code>export()</code> upon with pre-generated as a flattened list of
+     * Questions (with all sub-interviews removed).  In 43 and later, the
+     * structure is NOT flattened, but instead exporting will recurse into
+     * sub-interviews by calling its (the Interview) <code>export()</code>.
+     * Additionally, questions which are on the path but hidden will be exported.
+     * Note that being hidden is not the same at being disabled.
+     * </p>
+     *
+     * <p>
+     * In Version 50, FileListQuestion has significantly altered processing
+     * of filters.  See the {@link com.sun.interview.FileListQuestion#isValueValid}
+     * for an explanation.
+     * </p>
      *
      * @param value Which semantics the interview should use.
      * @see #SEMANTIC_PRE_32
      * @see #SEMANTIC_VERSION_32
+     * @see #SEMANTIC_VERSION_43
+     * @see #SEMANTIC_VERSION_50
      * @see #SEMANTIC_MAX_VERSION
      * @since 3.2
      * @see #getInterviewSemantics
@@ -2304,6 +2367,7 @@ public class Interview
         trimPath(q);
         predictPath(q);
         //showPath(this, q, 0);
+        verifyPredictPath();
 
         if (!pathContains(currPath[currPath.length - 1]))
             setCurrentQuestionFromPath(currPath);
@@ -2311,6 +2375,17 @@ public class Interview
         notifyPathUpdated();
     }
 
+    private void verifyPredictPath(){
+        for (Object o : getInterviews()){
+            if (o instanceof Interview){
+                Interview i = (Interview) o;
+                if (i.path != null && i.currIndex >= i.path.size()){
+                    i.currIndex = i.path.size()-1;
+                }
+            }
+        }
+    }
+
     /* useful debug routine
     private void showPath(Interview i, Question q, int depth) {
         for (int d = 0; d < depth; d++)
@@ -2666,6 +2741,18 @@ public class Interview
      */
     public static final int SEMANTIC_VERSION_43 = 2;
 
+    /**
+     *
+     * Where necessary, the harness interview should behave as it did for the
+     * 4.3 release.  This does not control every single possible change in
+     * behavior, but does control certain behaviors which may cause problems with
+     * interview code written against an earlier version of the harness.
+     *
+     *
+     * @see #setInterviewSemantics
+     */
+    public static final int SEMANTIC_VERSION_50 = 3;
+
     /**
      * The highest version number currently in use.  Note that the compiler
      * will probably inline this during compilation, so you will be locked at
@@ -2673,7 +2760,7 @@ public class Interview
      * behavior in this case.
      * @see #setInterviewSemantics
      */
-    public static final int SEMANTIC_MAX_VERSION = 2;
+    public static final int SEMANTIC_MAX_VERSION = 3;
 
     static class Path {
         void addQuestion(Question q) {
