@@ -758,7 +758,6 @@ public abstract class PropertiesQuestion extends CompositeQuestion
      */
     public String getGroupDisplayName(String group) {
         ResourceBundle b = interview.getResourceBundle();
-        presentationKeys = new HashMap();
         String rn = tag + "." + group + ".group";
 
         try {
@@ -809,6 +808,21 @@ public abstract class PropertiesQuestion extends CompositeQuestion
         if (value == null || value.getProperty(key) == null)
             throw new IllegalArgumentException("No such key: " + key);
 
+        if (c instanceof BooleanConstraints) {
+            if (value.getProperty(key) == null || value.getProperty(key).isEmpty()) {
+                if (defaultValue.getProperty(key) != null && !defaultValue.getProperty(key).isEmpty()) {
+                    value.put(key, defaultValue.getProperty(key));
+                }
+                else{
+                    if (((BooleanConstraints) c).isYesNo()){
+                        value.put(key, BooleanConstraints.NO);
+                    }
+                    else{
+                        value.put(key, BooleanConstraints.FALSE);
+                    }
+                }
+            }
+        }
         constraints.put(key, c);
     }
 
@@ -820,11 +834,35 @@ public abstract class PropertiesQuestion extends CompositeQuestion
      */
     public String getConstraintKeyFromRow(Object[] values) {
         if (values != null && values.length > 0 )
-            return values[0].toString();
+            return getKeyPropertyName(values[0].toString());
         else
             return "";
     }
 
+    /**
+     * Get the property name for displayed key value in the table
+     * @param key value of the key in the table
+     * @return key or the property name for the key
+     */
+    public String getKeyPropertyName(String key){
+        if (presentationKeys != null){
+            for (Object keyProperty : presentationKeys.keySet()){
+                if (key.equals(presentationKeys.get(keyProperty))){
+                    return (String) keyProperty;
+                }
+            }
+        }
+
+        return key;
+    }
+
+    /**
+     * Returns the localized key values to display
+     */
+    public HashMap getPresentationKeys(){
+        return presentationKeys;
+    }
+
     /**
      * @param key The key for the value to get constraints for.
      * @return Constraints object for the specified key, null if there are no
@@ -1404,6 +1442,12 @@ public abstract class PropertiesQuestion extends CompositeQuestion
      * Constraints allowing a value to be either a boolean or Yes/No response.
      */
     public static class BooleanConstraints extends ValueConstraints {
+
+        public final static String YES = "Yes";
+        public final static String NO = "No";
+        public final static String TRUE = "True";
+        public final static String FALSE = "False";
+
         public BooleanConstraints() {
             super();
         }
