@@ -32,7 +32,6 @@ import java.awt.Window;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.util.Map;
-import javax.help.HelpBroker;
 import javax.accessibility.AccessibleContext;
 import javax.swing.AbstractAction;
 import javax.swing.BorderFactory;
@@ -47,6 +46,7 @@ import javax.swing.SwingUtilities;
 import com.sun.interview.FinalQuestion;
 import com.sun.interview.Interview;
 import com.sun.interview.Question;
+import com.sun.javatest.tool.jthelp.HelpBroker;
 
 /**
  * A widget comprising the basic panels for a wizard: an index for the
