@@ -37,23 +37,12 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
-import java.io.BufferedInputStream;
-import java.io.BufferedOutputStream;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileNotFoundException;
-import java.io.FileOutputStream;
-import java.io.FileWriter;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.OutputStream;
-import java.io.Writer;
+import java.io.*;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.net.URL;
+import java.nio.charset.StandardCharsets;
 import java.util.Properties;
-import javax.help.HelpBroker;
-import javax.help.HelpSet;
 import javax.swing.BorderFactory;
 import javax.swing.Box;
 import javax.swing.Icon;
@@ -84,6 +73,9 @@ import javax.swing.filechooser.FileFilter;
 import com.sun.interview.Interview;
 import com.sun.interview.Question;
 import com.sun.interview.WizPrint;
+import com.sun.javatest.tool.jthelp.HelpBroker;
+import com.sun.javatest.tool.jthelp.HelpSet;
+import com.sun.javatest.tool.jthelp.JTHelpBroker;
 
 /**
  * A wizard to present an {@link Interview interview} consisting of
@@ -121,7 +113,7 @@ public class Wizard extends JComponent {
         try {
             UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
 
-            Class ic = (Class.forName(args[0]));
+            Class ic = (Class.forName(args[0], true, ClassLoader.getSystemClassLoader()));
             Interview i = (Interview)(ic.newInstance());
             Wizard w = new Wizard(i);
             w.showInFrame(true);
@@ -451,10 +443,10 @@ public class Wizard extends JComponent {
             helpHelpSet = infoPanel.getHelpSet();
 
         if (helpHelpBroker == null && helpHelpSet != null)
-            helpHelpBroker = helpHelpSet.createHelpBroker();
+            helpHelpBroker = new JTHelpBroker();
 
         if (helpHelpBroker != null && helpHelpSet != null)
-            helpHelpBroker.enableHelpKey(main, helpHelpPrefix + "window.csh", helpHelpSet);
+            helpHelpBroker.enableHelpKey(main, helpHelpPrefix + "window.csh");
         if (infoPanel == null)
             main.add(body);
         else
@@ -643,7 +635,7 @@ public class Wizard extends JComponent {
         if (f.exists() && !okToOverwrite(f))
             return;
         try {
-            Writer out = new FileWriter(f);
+            Writer out = new OutputStreamWriter(new FileOutputStream(f), StandardCharsets.UTF_8);
             WizPrint w = new WizPrint(interview, interview.getPath());
             w.setShowResponses(true);
             w.write(out);
@@ -684,8 +676,7 @@ public class Wizard extends JComponent {
      * Handle the "help" action
      */
     private void performHelp() {
-        helpHelpBroker.setCurrentID(helpHelpPrefix + "intro.csh");
-        helpHelpBroker.setDisplayed(true);
+        helpHelpBroker.displayCurrentID(helpHelpPrefix + "intro.csh");
     }
 
     /**
