@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 1996, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -38,6 +38,8 @@ import com.sun.javatest.util.BackupPolicy;
 import com.sun.javatest.util.DynamicArray;
 import com.sun.javatest.util.I18NResourceBundle;
 import com.sun.javatest.util.ReadAheadIterator;
+import java.util.HashMap;
+import java.util.Set;
 
 /**
  * The object responsible for coordinating the execution of a test run.
@@ -591,6 +593,7 @@ public class Harness
             throw new Fault(i18n, "harness.alreadyRunning");
 
         worker = new Thread() {
+            @Override
             public void run() {
                 boolean ok = false;
                 try {
@@ -690,33 +693,12 @@ public class Harness
             env.putUrlAndFile("testSuiteRootDir", testSuite.getRootDir());
         }
 
+
+        // notify the test suite we are starting
+        testSuite.starting(this);
+        notifier.startingTestRun(params);
+
         testIter = createTreeIterator();
-//      // get items required to select the tests to be run
-//      String[] tests = params.getTests();
-//      TestFilter[] filters = params.getFilters();
-//
-//      resultTable.waitUntilReady();
-//
-//      // get the appropriate iterator from TRT
-//      if (tests == null || tests.length == 0)
-//          testIter = resultTable.getIterator(filters);
-//      else {
-//          try {
-//              // CLEANUP REQUIRED: validation only occurs on Files, not Strings
-//              // resultTable.getIterator should validate strings too
-//              File[] files = new File[tests.length];
-//              for (int i = 0; i < tests.length; i++)
-//                  files[i] = new File(tests[i]);
-//              testIter = resultTable.getIterator(files, filters);
-//          }
-//          catch (TestResultTable.Fault err) {
-//              throw new Harness.Fault(i18n, "harness.badInitFiles",
-//                                      err.getMessage());
-//          }
-//      }
-//      // attach a read ahead iterator
-//      // use testIter to get specialized info, use raTestIter to get tests
-//      raTestIter = new ReadAheadIterator(testIter, readAheadMode, DEFAULT_READ_AHEAD);
         raTestIter = getTestsIterator(testIter);
 
         // autostopThreshold is currently defined by a system property,
@@ -724,13 +706,7 @@ public class Harness
         if (autostopThreshold > 0)
             addObserver(new Autostop(autostopThreshold));
 
-        // notify the test suite we are starting
-        testSuite.starting(this);
-
-        notifier.startingTestRun(params);
-
         TestRunner r = testSuite.createTestRunner();
-
         r.setWorkDirectory(workDir);
         r.setBackupPolicy(backupPolicy);
         r.setEnvironment(env);
@@ -786,7 +762,11 @@ public class Harness
             TestFilter[] filters = params.getFilters();
             // no tests are in the error, pass, fail categories -> none selected
             notifyError(i18n, "harness.noTests",
-                    formatFilterList(listFilterNames(filters)));
+                    new Object[] {
+                        formatFilterList(listFilterNames(filters)),
+                        testIter.getRejectCount(),
+                        formatFilterStats(params.getTests(), testIter)
+                    });
             ok = false;
         }
         else {
@@ -892,6 +872,47 @@ public class Harness
         return sb.toString();
     }
 
+    private static String formatFilterStats(final String[] tests,
+            final TreeIterator iter) {
+        TRT_Iterator treeit = null;
+
+        if (iter == null || !(iter instanceof TRT_Iterator)) {
+            return "";
+        }
+        else {
+            treeit = ((TRT_Iterator)iter);
+        }
+
+        TestFilter[] filters = treeit.getFilters();
+        HashMap<TestFilter, ArrayList<TestDescription>> map = treeit.getFilterStats();
+        Set<TestFilter> keyset = map.keySet();
+        StringBuilder sb = new StringBuilder();
+
+        // special case for Tests to Run because there is no associated
+        // TestFilter
+        if (tests != null && tests.length > 0) {
+            sb.append("- ");
+            sb.append("Tests to Run (" + tests.length + " path(s) specified)");
+            sb.append("\n");
+        }
+
+        for (TestFilter f: keyset) {
+            ArrayList<TestDescription> tds = map.get(f);
+            // this works, should consider switching to something which has more
+            // rendering control - RTF
+            sb.append("- ");
+            sb.append(tds.size());
+            sb.append(" due to ");        // could use upgrade for readability
+            sb.append(f.getName());
+            sb.append("\n");
+            sb.append("    ");      // indentation
+            sb.append(f.getReason());
+            sb.append("\n");
+        }   // for
+
+        return sb.toString();
+    }
+
 
     private void notifyError(I18NResourceBundle i18n, String key) {
         notifyLocalizedError(i18n.getString(key));
