@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2001, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2001, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -28,15 +28,16 @@ package com.sun.javatest;
 
 import java.util.ArrayList;
 import java.util.Enumeration;
-import java.util.Hashtable;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.NoSuchElementException;
 import java.util.Stack;
-import java.util.Vector;
 
+import com.sun.javatest.tool.Preferences;
 import com.sun.javatest.util.Debug;
 import com.sun.javatest.util.I18NResourceBundle;
+import java.util.Set;
 
 
 /**
@@ -65,6 +66,8 @@ class TRT_Iterator implements TestResultTable.TreeIterator {
         resultStats = new int[Status.NUM_STATES];
         nodeIndex = -1;
         currFrame = null;
+
+        setRecordRejects(true);
     }
 
     TRT_Iterator(TestResultTable.TreeNode node) {
@@ -243,11 +246,17 @@ class TRT_Iterator implements TestResultTable.TreeIterator {
         if (recordRejects == true) {
             // only create new objects if they don't exist
             // users can turn on and off this feature if they want
-            if (filteredTRs == null)
-                filteredTRs = new Hashtable(10);        // not likely to have > 10 filters
+            if (filteredTRs == null) {
+                filteredTRs = new HashMap(10);        // not likely to have > 10 filters
+            }
 
-            if (fo == null)
+            if (fo == null) {
                 fo = new FilterObserver();
+            }
+
+            if (rejLock == null) {
+                rejLock = new Object();
+            }
         }
     }
 
@@ -274,27 +283,24 @@ class TRT_Iterator implements TestResultTable.TreeIterator {
      * @return Array as described or null if no tests have been rejected yet.
      */
     @Override
-    public Hashtable getFilterStats() {
-        if (filteredTRs == null)
+    public HashMap<TestFilter, ArrayList<TestDescription>> getFilterStats() {
+        if (filteredTRs == null) {
             return null;
+        }
         else {
-            // create shallow, reformatted version of stored data
+            // create shallow copy
             // keys are TRs, values are TestFilters.
-            Hashtable out = new Hashtable();
+            HashMap<TestFilter, ArrayList<TestDescription>> out = new HashMap(filteredTRs.size());
 
             synchronized (rejLock) {
-                Enumeration keys = filteredTRs.keys();
+                Set keys = filteredTRs.keySet();
                 // each key is a TestFilter
-                while (keys.hasMoreElements()) {
+                Iterator<TestFilter> it = keys.iterator();
+                while (it.hasNext()) {
                     // could cast this to TestFilter, but why?
-                    Object thisKey = keys.nextElement();
-
-                    // the HT value is a Vector or TRs
-                    Iterator it = ((Vector)(filteredTRs.get(thisKey))).iterator();
-
-                    while (it.hasNext()) {
-                        out.put(it.next(), thisKey);
-                    }   // inner while
+                    TestFilter thisKey = it.next();
+                    ArrayList<TestDescription> al = (ArrayList<TestDescription>) filteredTRs.get(thisKey).clone();
+                    out.put(thisKey, al);
                 }   // outer while
             }   // sync
 
@@ -788,14 +794,17 @@ class TRT_Iterator implements TestResultTable.TreeIterator {
 
         absoluteCount++;
         currentResult = tr;
+        TestDescription td = tr.getDescription();
 
         for (int i = 0; i < filters.length; i++) {
             boolean accepted = true;
             try {
-                if (fo == null)
-                    accepted = filters[i].accepts(tr.getDescription());
-                else
-                    accepted = filters[i].accepts(tr.getDescription(), fo);
+                if (fo == null) {
+                    accepted = filters[i].accepts(td);
+                }
+                else {
+                    accepted = filters[i].accepts(td, fo);
+                }
             }
             catch (TestFilter.Fault f) {
                 accepted = true;
@@ -810,6 +819,15 @@ class TRT_Iterator implements TestResultTable.TreeIterator {
                 }
 
                 rejectCount++;
+
+                if (recordRejectTR && tr.getStatus().isNotRun()) {
+                    ArrayList<TestFilter> rejectors = getFullFilteredList(filters, td);
+                    // optimize this for shared Status objects
+                    Status newstatus = Status.notRun(generateFilteredStatus(rejectors));
+                    TestResult newone = new TestResult(td, newstatus);
+                    tr.getParent().getEnclosingTable().update(newone, true);
+                }
+
                 // rejected
                 return i;
             }
@@ -845,14 +863,68 @@ class TRT_Iterator implements TestResultTable.TreeIterator {
     }
 
     /**
-    private TestResultTable.TreeNode traverseToNode(TestResultTable.TreeNode start, String path) {
-        String curr;
-        TestResultTable.TreeNode pos;
+     * Query filter list to determine all the filters which would reject test.
+     * Necessary calculation because the rest of harness filtering typically fails fast
+     * on the first rejection.  Composite filters are not included in the search, only
+     * concrete filters are returned.
+     * @param filters Filters to check.
+     * @param td Tests to check.
+     * @return Null if the filter list is empty, array of size zero or greater
+     * otherwise.  Will be size zero if no filters reject the test.
+     */
+    private static ArrayList<TestFilter> getFullFilteredList(
+            final TestFilter[] filters,
+            final TestDescription td) {
+        if (td == null || filters == null || filters.length == 0) {
+            return null;
+        }
 
-        while (path != null) {
-        }   // while
+        final ArrayList<TestFilter> out = new ArrayList<TestFilter>();
+        TestFilter.Observer foo = new TestFilter.Observer() {
+            public void rejected(TestDescription td, TestFilter f) {
+                out.add(f);
+            }
+        };
+
+        for (TestFilter f : filters) {
+            try {
+                if (out.contains(f)) {
+                    // optimization
+                    continue;
+                }
+
+                f.accepts(td, foo);
+            }
+            catch (TestFilter.Fault fault) {
+                out.add(f);
+            }
+        }   // for
+
+        return out;
+    }
+
+    private static String generateFilteredStatus(ArrayList<TestFilter> fs) {
+        StringBuilder sb = new StringBuilder();
+
+        if (fs == null || fs.size() == 0) {
+            sb.append("Rejected by test filters.");
+        }
+        else {
+            sb.append("Rejected by test filters: " );
+
+            for (TestFilter f : fs) {
+                sb.append(f.getName());
+                sb.append(", ");
+            }
+        }
+        if (sb.length() > 2) {
+            return sb.substring(0, sb.length()-2);  // remove trailing ", "
+        }
+        else {
+            // exceptional case
+            return "";
+        }
     }
-    */
 
     /**
      * Tests (literally) that were provided by the client through one of the
@@ -875,15 +947,17 @@ class TRT_Iterator implements TestResultTable.TreeIterator {
     private int[] resultStats;          // pass/fail/error statistics
     private int absoluteCount;          // how many tests were processed
 
-
     // filter rejection info
     private int rejectCount;
     private boolean recordRejects;      // true when we are collecting reject stats
-    private Hashtable filteredTRs;      // key==TestFilter  value=Vector of TestResults
+    private HashMap<TestFilter, ArrayList<TestDescription>> filteredTRs;      // key==TestFilter  value=ArrayList of TestResults
     private TestResult currentResult;   // necessary communicate with filter observer, yuck
     private Object rejLock;
     private FilterObserver fo;          // null if feature is disabled
 
+    final Preferences p = Preferences.access();
+    boolean recordRejectTR = p.getPreference("exec.recordNotrunReasons", "false").equals("true");
+
     // ------ state information ------
     private Stack stack;
     private PseudoFrame currFrame;
@@ -942,13 +1016,13 @@ class TRT_Iterator implements TestResultTable.TreeIterator {
         @Override
         public void rejected(TestDescription d, TestFilter rejector) {
             synchronized (rejLock) {
-                Vector vec = (Vector)(filteredTRs.get(rejector));
+                ArrayList vec = filteredTRs.get(rejector);
                 if (vec == null) {
-                    vec = new Vector();
+                    vec = new ArrayList();
                     filteredTRs.put(rejector, vec);
                 }
 
-                // remove later...
+                // XXX remove later...
                 try {
                     if (currentResult.getDescription() != d)
                         throw new JavaTestError("TRT_Iterator observered TR.TD does not match filtered one.");
@@ -957,8 +1031,7 @@ class TRT_Iterator implements TestResultTable.TreeIterator {
                     throw new JavaTestError("TRT_Iterator cannot determine TR source info.", f);
                 }   // sanity check
 
-                vec.add(currentResult);
-
+                vec.add(d);
             }   // sync
         }
     }
