@@ -34,9 +34,12 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.TreeMap;
 
+import com.sun.javatest.logging.WorkDirLogHandler;
 import com.sun.javatest.util.Debug;
 import com.sun.javatest.util.Fifo;
 import com.sun.javatest.util.I18NResourceBundle;
+
+import java.util.logging.Handler;
 import java.util.logging.Logger;
 
 /**
@@ -448,6 +451,22 @@ public class TestResultCache {
             // ignore
         }
 
+        try {
+            if (workDir != null && workDir.getTestSuite() != null) {
+                Logger log = workDir.getTestSuite().getLog(workDir, i18n.getString("core.log.name"));
+                if (log != null && log.getHandlers() != null) {
+                    for (Handler handler : log.getHandlers()) {
+                        if (handler instanceof WorkDirLogHandler) {
+                            ((WorkDirLogHandler) handler).close();
+                        }
+                    }
+                }
+            }
+        }
+        catch (TestSuite.NoSuchLogFault noSuchLogFault) {
+            //nothing to do
+        }
+
         // important to avoid memory leak !!!
         try {
             if (shutdownHandler != null) {
@@ -516,7 +535,7 @@ public class TestResultCache {
                     catch (TestResult.ReloadFault e) {
                         // delete this jtr and continue
                         // should we inform TRT? perhaps via observer
-                        workDir.log(i18n, "trc.badjtr", f);
+                         workDir.log(i18n, "trc.badjtr", new Object[] {f, e.getLocalizedMessage()});
                         f.delete();
                     }
                 }
@@ -539,8 +558,8 @@ public class TestResultCache {
             return tr;
         }
         catch (TestResult.ReloadFault e) {
-                                // bad .jtr, delete it
-            workDir.log(i18n, "trc.badjtr", jtr);
+            // bad .jtr, delete it
+            workDir.log(i18n, "trc.badjtr", new Object[] {jtr, e.getLocalizedMessage()});
             jtr.delete();
             // this notRun status will persist in cache until cache rebuilt
             String name = tr.getTestName();
