@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 1996, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -37,6 +37,7 @@ import java.io.Writer;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
+import java.util.Arrays;
 import java.util.Enumeration;
 import java.util.MissingResourceException;
 import java.util.Vector;
@@ -49,7 +50,7 @@ import com.sun.javatest.util.Timer;
 import com.sun.javatest.util.WriterStream;
 
 /**
- * The means by which the tes harness executes requests on other machines.
+ * The means by which the the harness executes requests on other machines.
  * Agents are typically started by using one of AgentMain, AgentFrame,
  * or AgentApplet. The requests themselves are made from the harness
  * via AgentManager, or a library class that uses AgentManager.
@@ -574,7 +575,7 @@ public class Agent implements Runnable {
     }
 
     // The following is used to ensure consistency between Agent and AgentManager
-    static final short protocolVersion = 104;
+    static final short protocolVersion = 105;
 
     /**
      * The default port to which active agents will try and connect on a nominated host.
@@ -595,8 +596,8 @@ public class Agent implements Runnable {
     static final byte STATUS = (byte)'S';
 
     static final String productName = "JT Harness Agent";
-    static final String productVersion = "JTA_4.6";
-    static final String productCopyright = "Copyright (c) 1996, 2014, Oracle and/or its affiliates. All rights reserved.";
+    static final String productVersion = "JTA_5.0";
+    static final String productCopyright = "Copyright (c) 1996, 2016, Oracle and/or its affiliates. All rights reserved.";
 
 
     /**
@@ -764,6 +765,11 @@ public class Agent implements Runnable {
                 traceOut.println("sharedClassLoader: " + sharedClassLoader);
             }
 
+            timeoutValue = in.readInt();
+
+            if (tracing)
+                traceOut.println("COMMAND TIMEOUT(seconds) IS `" + timeoutValue + "'");
+
             byte guard = in.readByte();
             if (guard != 0)
                 throw new IOException("data format error");
@@ -780,8 +786,9 @@ public class Agent implements Runnable {
                 if (remoteClasses) {
                     cl = getAgentClassLoader(sharedClassLoader);
                     c = cl.loadClass(className);
-                } else
+                } else {
                     c = Class.forName(className);
+                }
 
                 if (request.equals("executeTest")) {
                     return executeTest(c, args, testLog, testRef);
@@ -789,8 +796,9 @@ public class Agent implements Runnable {
                     return executeCommand(c, args, testLog, testRef, cl);
                 } else if (request.equals("executeMain")) {
                     return executeMain(c, args, testLog, testRef);
-                } else
+                } else {
                     return Status.error("Unrecognized request for agent: `" + request + "'");
+                }
             } catch (ClassCastException e) {
                 if (tracing)
                     e.printStackTrace(traceOut);
@@ -842,7 +850,90 @@ public class Agent implements Runnable {
 
             Command tc = (Command)(c.newInstance());
             tc.setClassLoader(cl);
-            return tc.run(args, testLog, testRef);
+            return new CommandExecutor(tc, args, testLog, testRef, timeoutValue).execute();
+        }
+
+        private class CommandExecutor {
+
+            private String[] args;
+            private PrintWriter testLog;
+            private PrintWriter testRef;
+            private Command tc;
+            private Status result;
+
+            private final Object LOCK = new Object();
+            private boolean executed = false;
+            private boolean timeout = false;
+            private int timeoutValue = 0;
+
+            public CommandExecutor(Command tc, String[] args, PrintWriter testLog,
+                                        PrintWriter testRef, int timeoutValue) {
+                this.args = args;
+                this.testLog = testLog;
+                this.testRef = testRef;
+                this.tc = tc;
+                this.timeoutValue = timeoutValue;
+            }
+
+            public Status execute(){
+
+                Timer alarmTimer = null;
+                if (timeoutValue != 0) {
+                    alarmTimer = new Timer();
+                    alarmTimer.requestDelayedCallback(new Timer.Timeable() {
+                        @Override
+                        public void timeout() {
+                            result = Status.error("Marked as error by timeout after "+timeout+" seconds");
+                            timeout = true;
+                            synchronized (LOCK) {
+                                LOCK.notifyAll();
+                            }
+                        }
+                    }, timeoutValue * 1000);
+                }
+
+                Thread executeThread = new Thread(new Runnable() {
+                    @Override
+                    public void run() {
+                        try {
+                            result = tc.run(args, testLog, testRef);
+                        }
+                        catch (Exception e){
+                            result = Status.error("Unhandled " + e.getClass().getName() + " exception " +
+                                    "for " + tc.getClass().getName() + " command. " +
+                                    "Exception message: " + e.getMessage());
+                        }
+                        finally {
+                            executed = true;
+                            synchronized (LOCK) {
+                                LOCK.notifyAll();
+                            }
+                        }
+                    }
+                }, "CommandExecutor executeThread for command args: "+ Arrays.toString(args));
+                executeThread.start();
+
+                synchronized (LOCK) {
+                    while (!executed && !timeout) {
+                        try {
+                            LOCK.wait();
+                        }
+                        catch (InterruptedException e) {
+                            // treat interrupt as exit request
+                            break;
+                        }
+                    }
+                }
+
+                executeThread.setPriority(Thread.MIN_PRIORITY);
+                executeThread.interrupt();
+                if (alarmTimer != null){
+                    alarmTimer.finished();
+                }
+
+                return result;
+            }
+
         }
 
         private Status executeMain(Class c, String[] args,
@@ -905,7 +996,39 @@ public class Agent implements Runnable {
          */
         synchronized void sendChars(byte type, char b[], int off, int len) throws IOException {
             out.write(type);
-            out.writeUTF(new String(b, off, len));
+
+            String message = new String(b, off, len);
+            int strlen = message.length();
+            int utflen = 0;
+            int c, count = 0;
+
+            // shortcut if it's not possible to exceed the limit
+            if (strlen * 3 < 65535) {
+                count = strlen;
+            }
+            else {
+                /* count number of chars to meet 65535 bytes boundary */
+                for (int i = 0; i < strlen; i++) {
+                    c = message.charAt(i);
+                    if ((c >= 0x0001) && (c <= 0x007F)) {
+                        utflen++;
+                    } else if (c > 0x07FF) {
+                        utflen += 3;
+                    } else {
+                        utflen += 2;
+                    }
+
+                    // truncate here because we won't be able to encode more
+                    if (utflen > 65535) {
+                        break;
+                    } else {
+                        count = i;
+                    }
+                }   // for
+            }
+
+            out.writeUTF(message.substring(0, count));
+            //out.writeUTF(new String(b, off, len));
             switch (type) {
                 case LOG_FLUSH:
                 case REF_FLUSH:
@@ -925,7 +1048,7 @@ public class Agent implements Runnable {
         /**
          * Get the bytecodes for a class
          */
-        synchronized byte[] getClassData(String className) throws ClassNotFoundException {
+        synchronized AgentRemoteClassData getClassData(String className) throws ClassNotFoundException {
             if (tracing)
                 traceOut.println("REMOTE LOAD " + className);
 
@@ -934,31 +1057,11 @@ public class Agent implements Runnable {
                 out.writeUTF(className);
                 out.flush();
 
-                int size = in.readInt();
-                if (size == 0)
-                    throw new ClassNotFoundException(className);
-
-                byte[] data = new byte[size];
-                int offset = 0;
-                while (offset < data.length) {
-                    int n = in.read(data, offset, data.length - offset);
-                    if (n == -1)
-                        throw new ClassNotFoundException(className + ": EOF while reading class data");
-                    else
-                        offset += n;
+                AgentRemoteClassData classData = new AgentRemoteClassData(in);
+                if (tracing) {
+                    traceOut.println("REMOTE LOADED CLASS " + classData.toString());
                 }
-
-                //System.err.println(data.length);
-                //for (int i = 0; i < min(10, data.length); i++) {
-                //    System.err.print(data[i] + " ");
-                //}
-                //System.err.print(" ... ");
-                //for (int i = max(0, data.length - 10); i < data.length; i++) {
-                //    System.err.print(data[i] + " ");
-                //}
-                //System.err.println();
-
-                return data;
+                return classData;
             } catch (IOException e) {
                 throw new ClassNotFoundException(className + ": " + e);
             }
@@ -1025,6 +1128,7 @@ public class Agent implements Runnable {
             if (classLoaderConstructor == null) {
                 try {
                     classLoaderConstructor = classLoaderClass.getDeclaredConstructor(argTypes);
+                    classLoaderConstructor.setAccessible(true);
                 } catch (NoSuchMethodException e) {
                     e.printStackTrace();
                 }
@@ -1055,6 +1159,7 @@ public class Agent implements Runnable {
         private DataOutputStream out;
         private String tag;
         private String request;
+        private Integer timeoutValue;
     }
 
     private static Constructor classLoaderConstructor;
@@ -1090,8 +1195,12 @@ class AgentWriter extends Writer {
     public synchronized void write(int ch) throws IOException {
         buf[count++] = (char)ch;
         if (count == buf.length) {
-            parent.sendChars(type, buf, 0, count);
-            count = 0;
+            try {
+                parent.sendChars(type, buf, 0, count);
+            }
+            finally {
+                count = 0;
+            }
         }
     }
 
@@ -1142,8 +1251,12 @@ class AgentWriter extends Writer {
                 case Agent.LOG: type = Agent.LOG_FLUSH; break;
                 case Agent.REF: type = Agent.REF_FLUSH; break;
             }
-            parent.sendChars(type, buf, 0, count);
-            count = 0;
+            try {
+                parent.sendChars(type, buf, 0, count);
+            }
+            finally {
+                count = 0;
+            }
         }
     }
 
