@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 1996, 2014, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -30,6 +30,7 @@ import java.io.IOException;
 import java.io.PrintStream;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
+import java.util.HashMap;
 
 import com.sun.javatest.JavaTestSecurityManager;
 import com.sun.javatest.Status;
@@ -144,6 +145,24 @@ public class AgentMain {
         // installing a less permissive one; moan if it can't be installed.
         JavaTestSecurityManager.install();
 
+        if (Boolean.getBoolean("javatest.trace.printargs") &&
+            args != null && args.length > 0) {
+            StringBuffer fullCmd = new StringBuffer();
+            StringBuffer incrementalCmd = new StringBuffer();
+
+            for (int i = 0; i < args.length; i++) {
+                fullCmd.append(args[i]);
+                fullCmd.append(" ");
+
+                incrementalCmd.append("// ");
+                incrementalCmd.append(args[i]);
+                incrementalCmd.append("\n");
+            }   // for
+
+            System.out.println(fullCmd.toString().trim());
+            System.out.println(incrementalCmd.toString());
+        }
+
         int rc;
         try {
             run(args);
@@ -281,6 +300,9 @@ public class AgentMain {
             else if (args[i].equalsIgnoreCase("-map")) {
                 mapFile = args[++i];
                 return 2;
+            } else if (args[i].equalsIgnoreCase("-mapArg")) {
+                mappedArgs.put(args[++i], args[++i]);
+                return 3;
             }
             else if (args[i].equalsIgnoreCase("-trace")) {
                 tracing = true;
@@ -469,6 +491,8 @@ public class AgentMain {
                 String[] msgs = {"Problem reading map file", e.toString()};
                 throw new Fault(msgs);
             }
+        } else if (mappedArgs.size() > 0) {
+            agent.setMap(new Map(mappedArgs));
         }
 
         Integer delay = Integer.getInteger("agent.retry.delay");
@@ -495,6 +519,7 @@ public class AgentMain {
         out.println("        -passivePort port set the port for passive connections (implies -passive)");
         out.println("        -serialPort port  set the port for serial port connections");
         out.println("        -map file         map file for translating arguments of incoming requests");
+        out.println("        -mapArg from to   map \"from\" arg to \"to\" arg for incoming requests");
         out.println("        -concurrency num  set the maximum number of simultaneous connections");
         out.println("        -trace            trace the execution of the agent");
         out.println("        -observer class   add an observer to the agent");
@@ -522,6 +547,7 @@ public class AgentMain {
     private String serialPort = null;
     private int concurrency = 1;
     private String mapFile = null;
+    private java.util.Map<String, String> mappedArgs = new HashMap<String, String>();
     private String observerClassName;
     private boolean tracing;
 
@@ -536,14 +562,14 @@ public class AgentMain {
     private static class ErrorObserver implements Agent.Observer {
         ErrorObserver() {
             try {
-                connectExceptionClass = Class.forName("java.net.ConnectException");
+                connectExceptionClass = Class.forName("java.net.ConnectException", true, ClassLoader.getSystemClassLoader());
             }
             catch (Throwable t) {
                 // ignore
             }
 
             try {
-                unknownHostExceptionClass = Class.forName("java.net.UnknownHostException");
+                unknownHostExceptionClass = Class.forName("java.net.UnknownHostException", true, ClassLoader.getSystemClassLoader());
             }
             catch (Throwable t) {
                 // ignore
