@@ -30,13 +30,7 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ComponentAdapter;
 import java.awt.event.ComponentEvent;
-import java.io.BufferedWriter;
-import java.io.File;
-import java.io.FileNotFoundException;
-import java.io.FileWriter;
-import java.io.IOException;
-import java.io.StringWriter;
-import java.io.Writer;
+import java.io.*;
 import javax.swing.JButton;
 import javax.swing.JComponent;
 import javax.swing.JFileChooser;
@@ -53,6 +47,7 @@ import com.sun.javatest.tool.FileChooser;
 import com.sun.javatest.tool.ToolDialog;
 import com.sun.javatest.tool.UIFactory;
 import java.awt.Dimension;
+import java.nio.charset.StandardCharsets;
 import javax.swing.BorderFactory;
 
 class ChecklistBrowser extends ToolDialog
@@ -227,10 +222,10 @@ class ChecklistBrowser extends ToolDialog
             }
         }
 
-        FileWriter fw = null;
+        Writer fw = null;
         Writer out = null;
         try {
-            fw = new FileWriter(file);
+            fw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file), StandardCharsets.UTF_8));
             out = new BufferedWriter(fw);
             TextPane pane = (TextPane)body.getMediaPane(body.TEXT);
             out.write(pane.getText());
