@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Copyright (c) 2002, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,11 +26,8 @@
  */
 package com.sun.javatest.interview;
 
-import java.io.BufferedReader;
-import java.io.File;
-import java.io.FileNotFoundException;
-import java.io.FileReader;
-import java.io.IOException;
+import java.io.*;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.TreeSet;
@@ -195,7 +192,7 @@ public class TestsInterview
     private static final String TREE = "tree";
 
     /**
-     * Represents Tests Selection Choice Question. Exctracted to separate class
+     * Represents Tests Selection Choice Question. Extracted to separate class
      * for extensibility purposes
      */
     public class TreeOrFileChoiceQuestion extends ChoiceQuestion{
@@ -206,7 +203,7 @@ public class TestsInterview
         }
 
         /**
-         * Should be overriden if more selection choices are needed
+         * Should be overridden if more selection choices are needed
          * @return array of test selection choices
          */
         protected String[] getTestSelectionChoices(){
@@ -253,7 +250,7 @@ public class TestsInterview
     //
     // file
 
-    private FileQuestion qTestFile = new FileQuestion(this, "testFile") {
+    protected FileQuestion qTestFile = new FileQuestion(this, "testFile") {
         @Override
         public boolean isValueValid() {
             return (value != null && value.getPath().length() > 0);
@@ -281,10 +278,10 @@ public class TestsInterview
         }
     };
 
-    private String[] getTests(File file) {
+    protected String[] getTests(File file) {
         ArrayList<String> paths = new ArrayList();
         try {
-            BufferedReader in = new BufferedReader(new FileReader(file));
+            BufferedReader in = new BufferedReader(new InputStreamReader(new FileInputStream(file), StandardCharsets.UTF_8));
             String line;
             while ((line = in.readLine()) != null) {
                 line = line.trim();
@@ -331,7 +328,17 @@ public class TestsInterview
     private TreeQuestion.Model model = new TreeQuestion.Model() {
         @Override
         public Object getRoot() {
-            return parent.getWorkDirectory().getTestResultTable().getRoot();
+            // all the extra checks here because we know nulls can appear
+            if (parent == null || parent.getWorkDirectory() == null) {
+                return null;
+            }
+
+            WorkDirectory wd = parent.getWorkDirectory();
+            if (wd.getTestResultTable() == null) {
+                return null;
+            }
+
+            return wd.getTestResultTable().getRoot();
         }
 
         @Override
@@ -519,7 +526,7 @@ public class TestsInterview
     };
 
     private String[] cachedTestsValue;
-    private Question cachedTestsError;
+    protected Question cachedTestsError;
     private Object[] cachedTestsErrorArgs;
 
     //----------------------------------------------------------------------------
