@@ -33,14 +33,9 @@ import com.sun.javatest.report.ReportFormat.ReportLink;
 import com.sun.javatest.tool.Preferences;
 import com.sun.javatest.util.BackupUtil;
 import com.sun.javatest.util.I18NResourceBundle;
-import java.io.BufferedReader;
-import java.io.BufferedWriter;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileWriter;
-import java.io.IOException;
-import java.io.InputStreamReader;
-import java.io.Writer;
+
+import java.io.*;
+import java.nio.charset.StandardCharsets;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -170,22 +165,22 @@ public class Report implements ReportModel {
      * from the preferences will be used.
      * @throws IllegalArgumentException if the type parameter does not
      *         identify a proper report type.
-     * @param type The report type identifier, may be a custom type.
+     * @param types The report type identifiers, may be a custom type.
      *              null for default generated reports
      * @throws java.io.IOException If an error occurs writing any of the files.
      */
-    public void writeReport(String type) throws IOException {
+    public void writeReport(String... types) throws IOException {
         // make a settings object - default settings
         //Settings settings = new Settings(params);
         ReportSettings settings = getSettingsPrefs();
         settings.setInterview(params);
 
         String[] typesToGen;
-        if (type == null) {
+        if (types == null) {
             // if type is not specified generate html and plain text
             typesToGen = new String[] {"html", "txt"};
         } else {
-            typesToGen = new String[] {type};
+            typesToGen = Arrays.copyOf(types, types.length);
         }
 
         // this setting can originate in a legacy constructor
@@ -213,7 +208,10 @@ public class Report implements ReportModel {
             doCLReport(rf, settings, typesToGen, links);
         }
         if (links.isEmpty()) {
-            throw new IllegalArgumentException("Unknown report type: " + type);
+            throw new IllegalArgumentException("Unknown report types: " + Arrays.toString(types));
+        }
+        if (links.size() != typesToGen.length) {
+            throw new IllegalArgumentException("Not all report types are known: " + Arrays.toString(types));
         }
 
         updateStaffFiles(reportDir, settings, links);
@@ -358,7 +356,7 @@ public class Report implements ReportModel {
             StringBuilder content = new StringBuilder();
             BufferedReader r = null;
             try {
-                r = new BufferedReader(new InputStreamReader(new FileInputStream(index)));
+                r = new BufferedReader(new InputStreamReader(new FileInputStream(index), StandardCharsets.UTF_8));
                 String line;
                 while( (line = r.readLine()) != null ) {
                     content.append(line);
@@ -417,7 +415,7 @@ public class Report implements ReportModel {
         StringBuilder sb = new StringBuilder();
         BufferedReader r = null;
         try {
-            r = new BufferedReader(new InputStreamReader(new FileInputStream(index)));
+            r = new BufferedReader(new InputStreamReader(new FileInputStream(index), StandardCharsets.UTF_8));
             String line;
             while( (line = r.readLine()) != null ) {
                 sb.append(line);
@@ -461,7 +459,7 @@ public class Report implements ReportModel {
 
         Writer writer = null;
         try {
-            writer = new BufferedWriter(new FileWriter(index));
+            writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(index), StandardCharsets.UTF_8));
             writer.write(sb.toString());
             writer.flush();
             writer.close();
@@ -505,7 +503,7 @@ public class Report implements ReportModel {
     private void fillIndexFile(File index, ReportSettings s,  List<ReportLink> links) {
         Writer writer = null;
         try {
-            writer = new BufferedWriter(new FileWriter(index));
+            writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(index), StandardCharsets.UTF_8));
             HTMLWriterEx out = new HTMLWriterEx(writer);
             out.setI18NResourceBundle(i18n);
 
