@@ -40,17 +40,13 @@ import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.io.BufferedWriter;
-import java.io.FileWriter;
-import java.io.OutputStreamWriter;
-import java.io.Writer;
-import java.io.IOException;
+import java.io.*;
+import java.nio.charset.StandardCharsets;
 import java.util.Iterator;
 import java.util.Set;
 import java.util.Vector;
 import java.beans.PropertyChangeListener;
 import javax.accessibility.AccessibleContext;
-import javax.help.JHelpContentViewer;
 import javax.swing.AbstractAction;
 import javax.swing.Action;
 import javax.swing.ActionMap;
@@ -79,6 +75,7 @@ import javax.swing.event.MenuEvent;
 import javax.swing.event.MenuListener;
 import javax.swing.text.Document;
 import javax.swing.text.JTextComponent;
+import com.sun.javatest.tool.jthelp.JHelpContentViewer;
 
 class FocusMonitor
 {
@@ -155,7 +152,7 @@ class FocusMonitor
                     };
             }
             else
-                out = new BufferedWriter(new FileWriter(reportFile, true));
+                out = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(reportFile, true), StandardCharsets.UTF_8));
 
             out.write("---------------------------------------");
             out.write(NEWLINE);
